@@ -77,7 +77,7 @@ func (gm *gitalyMake) GoVendor() string          { return "bin/govendor" }
 func (gm *gitalyMake) StaticCheck() string       { return filepath.Join(gm.BuildDir(), "bin/staticcheck") }
 func (gm *gitalyMake) CoverageDir() string       { return filepath.Join(gm.BuildDir(), "cover") }
 func (gm *gitalyMake) GitalyRubyDir() string     { return filepath.Join(gm.SourceDir(), "ruby") }
-func (gm *gitalyMake) GitlabShellRelDir() string { return "ruby/vendor/gitlab-shell" }
+func (gm *gitalyMake) GitlabShellRelDir() string { return "ruby/gitlab-shell" }
 func (gm *gitalyMake) GitlabShellDir() string {
 	return filepath.Join(gm.SourceDir(), gm.GitlabShellRelDir())
 }
@@ -145,21 +145,44 @@ func (gm *gitalyMake) GoLdFlags() string {
 	return fmt.Sprintf("-ldflags '-X %s/internal/version.version=%s -X %s/internal/version.buildtime=%s'", gm.Pkg(), gm.Version(), gm.Pkg(), gm.BuildTime())
 }
 
+func (gm *gitalyMake) VersionFromFile() string {
+	data, err := ioutil.ReadFile("../VERSION")
+	if err != nil {
+		log.Printf("error obtaining version from file: %v", err)
+		return ""
+	}
+
+	return fmt.Sprintf("v%s", strings.TrimSpace(string(data)))
+}
+
+func (gm *gitalyMake) VersionFromGit() string {
+	cmd := exec.Command("git", "describe")
+	cmd.Stderr = os.Stderr
+	out, err := cmd.Output()
+	if err != nil {
+		log.Printf("error obtaining version from git: %s: %v", strings.Join(cmd.Args, " "), err)
+		return ""
+	}
+
+	return strings.TrimSpace(string(out))
+}
+
 func (gm *gitalyMake) VersionPrefixed() string {
 	if len(gm.versionPrefixed) > 0 {
 		return gm.versionPrefixed
 	}
 
-	cmd := exec.Command("git", "describe")
-	cmd.Stderr = os.Stderr
-	out, err := cmd.Output()
-	if err != nil {
-		log.Printf("%s: %v", strings.Join(cmd.Args, " "), err)
-		gm.versionPrefixed = "unknown"
-		return gm.versionPrefixed
+	version := gm.VersionFromGit()
+	if version == "" {
+		log.Printf("Attempting to get the version from file")
+		version = gm.VersionFromFile()
 	}
-	gm.versionPrefixed = strings.TrimSpace(string(out))
 
+	if version == "" {
+		version = "unknown"
+	}
+
+	gm.versionPrefixed = version
 	return gm.versionPrefixed
 }
 
@@ -244,7 +267,8 @@ all: build
 
 .PHONY: build
 build: ../.ruby-bundle
-	go install {{ .GoLdFlags }} -tags "$(BUILD_TAGS)" {{ join .CommandPackages " " }}
+	# go install
+	@cd {{ .SourceDir }} && go install {{ .GoLdFlags }} -tags "$(BUILD_TAGS)" {{ join .CommandPackages " " }}
 
 # This file is used by Omnibus and CNG to skip the "bundle install"
 # step. Both Omnibus and CNG assume it is in the Gitaly root, not in
@@ -346,7 +370,7 @@ lint: {{ .GoLint }}
 	@cd {{ .SourceDir }} && go run _support/lint.go
 
 {{ .GoLint }}:
-	go get golang.org/x/lint/golint
+	go install {{ .SourceDir }}/vendor/golang.org/x/lint/golint
 
 .PHONY: check-formatting
 check-formatting: {{ .GoImports }}
@@ -354,7 +378,7 @@ check-formatting: {{ .GoImports }}
 	@cd {{ .SourceDir }} && goimports -e -l {{ join .GoFiles " " }} | awk '{ print } END { if(NR>0) { print "Formatting error, run make format"; exit(1) } }'
 
 {{ .GoImports }}:
-	go get golang.org/x/tools/cmd/goimports
+	go install {{ .SourceDir }}/vendor/golang.org/x/tools/cmd/goimports
 
 .PHONY: format
 format: {{ .GoImports }}
@@ -369,7 +393,7 @@ staticcheck: {{ .StaticCheck }}
 
 # Install staticcheck
 {{ .StaticCheck }}:
-	go get honnef.co/go/tools/cmd/staticcheck
+	go install {{ .SourceDir }}/vendor/honnef.co/go/tools/cmd/staticcheck
 
 .PHONY: govendor-status
 govendor-status: {{ .GoVendor }}
@@ -377,7 +401,7 @@ govendor-status: {{ .GoVendor }}
 	@cd {{ .SourceDir }} && govendor status
 
 {{ .GoVendor }}:
-	go get github.com/kardianos/govendor
+	go install {{ .SourceDir }}/vendor/github.com/kardianos/govendor
 
 .PHONY: notice-up-to-date
 notice-up-to-date: {{ .GoVendor }} clean-ruby-vendor-go
@@ -415,7 +439,7 @@ cover: prepare-tests {{ .GoCovMerge }}
 	@go tool cover -func "{{ .CoverageDir }}/all.merged"
 
 {{ .GoCovMerge }}:
-	go get github.com/wadey/gocovmerge
+	go install {{ .SourceDir }}/vendor/github.com/wadey/gocovmerge
 
 .PHONY: docker
 docker:
