@@ -1,9 +1,9 @@
 package featureflag
 
 import (
+	"context"
 	"fmt"
 
-	"golang.org/x/net/context"
 	"google.golang.org/grpc/metadata"
 )
 
