@@ -1,10 +1,10 @@
 package featureflag
 
 import (
+	"context"
 	"testing"
 
 	"github.com/stretchr/testify/assert"
-	"golang.org/x/net/context"
 	"google.golang.org/grpc/metadata"
 )
 
