@@ -8,8 +8,6 @@ import (
 	"sync"
 
 	"gitlab.com/gitlab-org/gitaly/internal/git"
-	"google.golang.org/grpc/codes"
-	"google.golang.org/grpc/status"
 )
 
 // batchCheck encapsulates a 'git cat-file --batch-check' process
@@ -27,7 +25,7 @@ func newBatchCheck(ctx context.Context, repoPath string, env []string) (*batchCh
 	batchCmdArgs := []string{"--git-dir", repoPath, "cat-file", "--batch-check"}
 	batchCmd, err := git.BareCommand(ctx, stdinReader, nil, nil, env, batchCmdArgs...)
 	if err != nil {
-		return nil, status.Errorf(codes.Internal, "CatFile: cmd: %v", err)
+		return nil, err
 	}
 	bc.r = bufio.NewReader(batchCmd)
 	go func() {
