@@ -1,10 +1,11 @@
 package commit
 
 import (
+	"context"
+
 	"gitlab.com/gitlab-org/gitaly-proto/go/gitalypb"
 	"gitlab.com/gitlab-org/gitaly/internal/git"
 	"gitlab.com/gitlab-org/gitaly/internal/git/log"
-	"golang.org/x/net/context"
 	"google.golang.org/grpc/codes"
 	"google.golang.org/grpc/status"
 )
@@ -18,5 +19,9 @@ func (s *server) FindCommit(ctx context.Context, in *gitalypb.FindCommitRequest)
 	repo := in.GetRepository()
 
 	commit, err := log.GetCommit(ctx, repo, string(revision))
+	if log.IsNotFound(err) {
+		return &gitalypb.FindCommitResponse{}, nil
+	}
+
 	return &gitalypb.FindCommitResponse{Commit: commit}, err
 }
