@@ -2,6 +2,8 @@ package objectpool
 
 import (
 	"context"
+	"errors"
+	"fmt"
 
 	"gitlab.com/gitlab-org/gitaly-proto/go/gitalypb"
 	"gitlab.com/gitlab-org/gitaly/internal/helper"
@@ -28,16 +30,20 @@ func (s *server) LinkRepositoryToObjectPool(ctx context.Context, req *gitalypb.L
 
 func (s *server) UnlinkRepositoryFromObjectPool(ctx context.Context, req *gitalypb.UnlinkRepositoryFromObjectPoolRequest) (*gitalypb.UnlinkRepositoryFromObjectPoolResponse, error) {
 	if req.GetRepository() == nil {
-		return nil, status.Error(codes.InvalidArgument, "no repository")
+		return nil, helper.ErrInvalidArgument(errors.New("no repository"))
 	}
 
 	pool, err := poolForRequest(req)
 	if err != nil {
-		return nil, err
+		return nil, helper.ErrInternal(err)
+	}
+
+	if !pool.Exists() {
+		return nil, helper.ErrNotFound(fmt.Errorf("pool repository not found: %s", pool.FullPath()))
 	}
 
 	if err := pool.Unlink(ctx, req.GetRepository()); err != nil {
-		return nil, err
+		return nil, helper.ErrInternal(err)
 	}
 
 	return &gitalypb.UnlinkRepositoryFromObjectPoolResponse{}, nil
