@@ -8,6 +8,7 @@ import (
 	"github.com/stretchr/testify/require"
 	"gitlab.com/gitlab-org/gitaly-proto/go/gitalypb"
 	"gitlab.com/gitlab-org/gitaly/internal/git/log"
+	"gitlab.com/gitlab-org/gitaly/internal/helper/text"
 	"gitlab.com/gitlab-org/gitaly/internal/service/operations"
 	"gitlab.com/gitlab-org/gitaly/internal/testhelper"
 	"google.golang.org/grpc/codes"
@@ -90,7 +91,9 @@ func TestSuccessfulUserCommitFilesRequest(t *testing.T) {
 	for _, tc := range testCases {
 		t.Run(tc.desc, func(t *testing.T) {
 			ctx := metadata.NewOutgoingContext(ctxOuter, md)
-			headerRequest := headerRequest(tc.repo, user, tc.branchName, commitFilesMessage, authorName, authorEmail)
+			headerRequest := headerRequest(tc.repo, user, tc.branchName, commitFilesMessage)
+			setAuthorAndEmail(headerRequest, authorName, authorEmail)
+
 			actionsRequest1 := createFileHeaderRequest(filePath)
 			actionsRequest2 := actionContentRequest("My")
 			actionsRequest3 := actionContentRequest(" content")
@@ -162,7 +165,8 @@ func TestSuccessfulUserCommitFilesRequestMove(t *testing.T) {
 			origFileContent := testhelper.MustRunCommand(t, nil, "git", "-C", testRepoPath, "show", branchName+":"+previousFilePath)
 			md := testhelper.GitalyServersMetadata(t, serverSocketPath)
 			ctx := metadata.NewOutgoingContext(ctxOuter, md)
-			headerRequest := headerRequest(testRepo, user, branchName, commitFilesMessage, authorName, authorEmail)
+			headerRequest := headerRequest(testRepo, user, branchName, commitFilesMessage)
+			setAuthorAndEmail(headerRequest, authorName, authorEmail)
 			actionsRequest1 := moveFileHeaderRequest(previousFilePath, filePath, tc.infer)
 
 			stream, err := client.UserCommitFiles(ctx)
@@ -192,6 +196,58 @@ func TestSuccessfulUserCommitFilesRequestMove(t *testing.T) {
 	}
 }
 
+func TestSuccessfulUserCommitFilesRequestForceCommit(t *testing.T) {
+	server, serverSocketPath := runFullServer(t)
+	defer server.Stop()
+
+	client, conn := operations.NewOperationClient(t, serverSocketPath)
+	defer conn.Close()
+
+	testRepo, testRepoPath, cleanupFn := testhelper.NewTestRepo(t)
+	defer cleanupFn()
+
+	ctxOuter, cancel := testhelper.Context()
+	defer cancel()
+
+	md := testhelper.GitalyServersMetadata(t, serverSocketPath)
+	ctx := metadata.NewOutgoingContext(ctxOuter, md)
+	authorName := []byte("Jane Doe")
+	authorEmail := []byte("janedoe@gitlab.com")
+	targetBranchName := "feature"
+	startBranchName := []byte("master")
+
+	startBranchCommit, err := log.GetCommit(ctxOuter, testRepo, string(startBranchName))
+	require.NoError(t, err)
+
+	targetBranchCommit, err := log.GetCommit(ctxOuter, testRepo, targetBranchName)
+	require.NoError(t, err)
+
+	mergeBaseOut := testhelper.MustRunCommand(t, nil, "git", "-C", testRepoPath, "merge-base", targetBranchCommit.Id, startBranchCommit.Id)
+	mergeBaseID := text.ChompBytes(mergeBaseOut)
+	require.NotEqual(t, mergeBaseID, targetBranchCommit.Id, "expected %s not to be an ancestor of %s", targetBranchCommit.Id, startBranchCommit.Id)
+
+	headerRequest := headerRequest(testRepo, user, targetBranchName, commitFilesMessage)
+	setAuthorAndEmail(headerRequest, authorName, authorEmail)
+	setStartBranchName(headerRequest, startBranchName)
+	setForce(headerRequest, true)
+
+	stream, err := client.UserCommitFiles(ctx)
+	require.NoError(t, err)
+	require.NoError(t, stream.Send(headerRequest))
+	require.NoError(t, stream.Send(createFileHeaderRequest("TEST.md")))
+	require.NoError(t, stream.Send(actionContentRequest("Test")))
+
+	r, err := stream.CloseAndRecv()
+	require.NoError(t, err)
+
+	update := r.GetBranchUpdate()
+	newTargetBranchCommit, err := log.GetCommit(ctxOuter, testRepo, targetBranchName)
+	require.NoError(t, err)
+
+	require.Equal(t, newTargetBranchCommit.Id, update.CommitId)
+	require.Equal(t, newTargetBranchCommit.ParentIds, []string{startBranchCommit.Id})
+}
+
 func TestFailedUserCommitFilesRequestDueToHooks(t *testing.T) {
 	server, serverSocketPath := runFullServer(t)
 	defer server.Stop()
@@ -207,7 +263,7 @@ func TestFailedUserCommitFilesRequestDueToHooks(t *testing.T) {
 
 	branchName := "feature"
 	filePath := "my/file.txt"
-	headerRequest := headerRequest(testRepo, user, branchName, commitFilesMessage, nil, nil)
+	headerRequest := headerRequest(testRepo, user, branchName, commitFilesMessage)
 	actionsRequest1 := createFileHeaderRequest(filePath)
 	actionsRequest2 := actionContentRequest("My content")
 	hookContent := []byte("#!/bin/sh\nprintenv | paste -sd ' ' -\nexit 1")
@@ -258,7 +314,7 @@ func TestFailedUserCommitFilesRequestDueToIndexError(t *testing.T) {
 		{
 			desc: "file already exists",
 			requests: []*gitalypb.UserCommitFilesRequest{
-				headerRequest(testRepo, user, "feature", commitFilesMessage, nil, nil),
+				headerRequest(testRepo, user, "feature", commitFilesMessage),
 				createFileHeaderRequest("README.md"),
 				actionContentRequest("This file already exists"),
 			},
@@ -267,7 +323,7 @@ func TestFailedUserCommitFilesRequestDueToIndexError(t *testing.T) {
 		{
 			desc: "file doesn't exists",
 			requests: []*gitalypb.UserCommitFilesRequest{
-				headerRequest(testRepo, user, "feature", commitFilesMessage, nil, nil),
+				headerRequest(testRepo, user, "feature", commitFilesMessage),
 				chmodFileHeaderRequest("documents/story.txt", true),
 			},
 			indexError: "A file with this name doesn't exist",
@@ -275,7 +331,7 @@ func TestFailedUserCommitFilesRequestDueToIndexError(t *testing.T) {
 		{
 			desc: "dir already exists",
 			requests: []*gitalypb.UserCommitFilesRequest{
-				headerRequest(testRepo, user, "utf-dir", commitFilesMessage, nil, nil),
+				headerRequest(testRepo, user, "utf-dir", commitFilesMessage),
 				actionRequest(&gitalypb.UserCommitFilesAction{
 					UserCommitFilesActionPayload: &gitalypb.UserCommitFilesAction_Header{
 						Header: &gitalypb.UserCommitFilesActionHeader{
@@ -329,19 +385,19 @@ func TestFailedUserCommitFilesRequest(t *testing.T) {
 	}{
 		{
 			desc: "empty Repository",
-			req:  headerRequest(nil, user, branchName, commitFilesMessage, nil, nil),
+			req:  headerRequest(nil, user, branchName, commitFilesMessage),
 		},
 		{
 			desc: "empty User",
-			req:  headerRequest(testRepo, nil, branchName, commitFilesMessage, nil, nil),
+			req:  headerRequest(testRepo, nil, branchName, commitFilesMessage),
 		},
 		{
 			desc: "empty BranchName",
-			req:  headerRequest(testRepo, user, "", commitFilesMessage, nil, nil),
+			req:  headerRequest(testRepo, user, "", commitFilesMessage),
 		},
 		{
 			desc: "empty CommitMessage",
-			req:  headerRequest(testRepo, user, branchName, nil, nil, nil),
+			req:  headerRequest(testRepo, user, branchName, nil),
 		},
 	}
 
@@ -359,23 +415,41 @@ func TestFailedUserCommitFilesRequest(t *testing.T) {
 	}
 }
 
-func headerRequest(repo *gitalypb.Repository, user *gitalypb.User, branchName string, commitMessage, authorName, authorEmail []byte) *gitalypb.UserCommitFilesRequest {
+func headerRequest(repo *gitalypb.Repository, user *gitalypb.User, branchName string, commitMessage []byte) *gitalypb.UserCommitFilesRequest {
 	return &gitalypb.UserCommitFilesRequest{
 		UserCommitFilesRequestPayload: &gitalypb.UserCommitFilesRequest_Header{
 			Header: &gitalypb.UserCommitFilesRequestHeader{
-				Repository:        repo,
-				User:              user,
-				BranchName:        []byte(branchName),
-				CommitMessage:     commitMessage,
-				CommitAuthorName:  authorName,
-				CommitAuthorEmail: authorEmail,
-				StartBranchName:   nil,
-				StartRepository:   nil,
+				Repository:      repo,
+				User:            user,
+				BranchName:      []byte(branchName),
+				CommitMessage:   commitMessage,
+				StartBranchName: nil,
+				StartRepository: nil,
 			},
 		},
 	}
 }
 
+func setAuthorAndEmail(headerRequest *gitalypb.UserCommitFilesRequest, authorName, authorEmail []byte) {
+	header := getHeader(headerRequest)
+	header.CommitAuthorName = authorName
+	header.CommitAuthorEmail = authorEmail
+}
+
+func setStartBranchName(headerRequest *gitalypb.UserCommitFilesRequest, startBranchName []byte) {
+	header := getHeader(headerRequest)
+	header.StartBranchName = startBranchName
+}
+
+func setForce(headerRequest *gitalypb.UserCommitFilesRequest, force bool) {
+	header := getHeader(headerRequest)
+	header.Force = force
+}
+
+func getHeader(headerRequest *gitalypb.UserCommitFilesRequest) *gitalypb.UserCommitFilesRequestHeader {
+	return headerRequest.UserCommitFilesRequestPayload.(*gitalypb.UserCommitFilesRequest_Header).Header
+}
+
 func createFileHeaderRequest(filePath string) *gitalypb.UserCommitFilesRequest {
 	return actionRequest(&gitalypb.UserCommitFilesAction{
 		UserCommitFilesActionPayload: &gitalypb.UserCommitFilesAction_Header{
