@@ -13,6 +13,7 @@ import (
 	"github.com/stretchr/testify/require"
 	"gitlab.com/gitlab-org/gitaly-proto/go/gitalypb"
 	gitlog "gitlab.com/gitlab-org/gitaly/internal/git/log"
+	"gitlab.com/gitlab-org/gitaly/internal/helper/text"
 	"gitlab.com/gitlab-org/gitaly/internal/testhelper"
 	"google.golang.org/grpc/codes"
 )
@@ -273,7 +274,7 @@ func TestFailedMergeDueToHooks(t *testing.T) {
 			require.NoError(t, err, "consume EOF")
 
 			currentBranchHead := testhelper.MustRunCommand(t, nil, "git", "-C", testRepoPath, "rev-parse", mergeBranchName)
-			require.Equal(t, mergeBranchHeadBefore, strings.TrimSpace(string(currentBranchHead)), "branch head updated")
+			require.Equal(t, mergeBranchHeadBefore, text.ChompBytes(currentBranchHead), "branch head updated")
 		})
 	}
 
@@ -315,7 +316,7 @@ func TestSuccessfulUserFFBranchRequest(t *testing.T) {
 	require.NoError(t, err)
 	require.Equal(t, expectedResponse, resp)
 	newBranchHead := testhelper.MustRunCommand(t, nil, "git", "-C", testRepoPath, "rev-parse", branchName)
-	require.Equal(t, commitID, strings.TrimSpace(string(newBranchHead)), "branch head not updated")
+	require.Equal(t, commitID, text.ChompBytes(newBranchHead), "branch head not updated")
 }
 
 func TestFailedUserFFBranchRequest(t *testing.T) {
@@ -453,6 +454,239 @@ func TestFailedUserFFBranchDueToHooks(t *testing.T) {
 	}
 }
 
+func TestSuccessfulUserMergeToRefRequest(t *testing.T) {
+	server, serverSocketPath := runOperationServiceServer(t)
+	defer server.Stop()
+
+	client, conn := newOperationClient(t, serverSocketPath)
+	defer conn.Close()
+
+	testRepo, testRepoPath, cleanupFn := testhelper.NewTestRepo(t)
+	defer cleanupFn()
+
+	prepareMergeBranch(t, testRepoPath)
+
+	existingTargetRef := []byte("refs/merge-requests/x/written")
+	emptyTargetRef := []byte("refs/merge-requests/x/merge")
+	mergeCommitMessage := "Merged by Gitaly"
+
+	// Writes in existingTargetRef
+	beforeRefreshCommitSha := "a5391128b0ef5d21df5dd23d98557f4ef12fae20"
+	out, err := exec.Command("git", "-C", testRepoPath, "update-ref", string(existingTargetRef), beforeRefreshCommitSha).CombinedOutput()
+	require.NoError(t, err, "give an existing state to the target ref: %s", out)
+
+	testCases := []struct {
+		desc      string
+		user      *gitalypb.User
+		branch    []byte
+		targetRef []byte
+		emptyRef  bool
+		sourceSha string
+		message   string
+	}{
+		{
+			desc:      "empty target ref merge",
+			user:      mergeUser,
+			branch:    []byte(mergeBranchName),
+			targetRef: emptyTargetRef,
+			emptyRef:  true,
+			sourceSha: commitToMerge,
+			message:   mergeCommitMessage,
+		},
+		{
+			desc:      "existing target ref",
+			user:      mergeUser,
+			branch:    []byte(mergeBranchName),
+			targetRef: existingTargetRef,
+			emptyRef:  false,
+			sourceSha: commitToMerge,
+			message:   mergeCommitMessage,
+		},
+	}
+
+	for _, testCase := range testCases {
+		t.Run(testCase.desc, func(t *testing.T) {
+			ctx, cancel := testhelper.Context()
+			defer cancel()
+
+			request := &gitalypb.UserMergeToRefRequest{
+				Repository: testRepo,
+				User:       testCase.user,
+				Branch:     testCase.branch,
+				TargetRef:  testCase.targetRef,
+				SourceSha:  testCase.sourceSha,
+				Message:    []byte(testCase.message),
+			}
+
+			commitBeforeRefMerge, fetchRefBeforeMergeErr := gitlog.GetCommit(ctx, testRepo, string(testCase.targetRef))
+			if testCase.emptyRef {
+				require.Error(t, fetchRefBeforeMergeErr, "error when fetching empty ref commit")
+			} else {
+				require.NoError(t, fetchRefBeforeMergeErr, "no error when fetching existing ref")
+			}
+
+			resp, err := client.UserMergeToRef(ctx, request)
+			require.NoError(t, err)
+
+			commit, err := gitlog.GetCommit(ctx, testRepo, string(testCase.targetRef))
+			require.NoError(t, err, "look up git commit after call has finished")
+
+			// Asserts commit parent SHAs
+			require.Equal(t, []string{mergeBranchHeadBefore, testCase.sourceSha}, commit.ParentIds, "merge commit parents must be the sha before HEAD and source sha")
+
+			require.True(t, strings.HasPrefix(string(commit.Body), testCase.message), "expected %q to start with %q", commit.Body, testCase.message)
+
+			// Asserts author
+			author := commit.Author
+			require.Equal(t, mergeUser.Name, author.Name)
+			require.Equal(t, mergeUser.Email, author.Email)
+
+			require.Equal(t, resp.CommitId, commit.Id)
+
+			// Calling commitBeforeRefMerge.Id in a non-existent
+			// commit will raise a null-pointer error.
+			if !testCase.emptyRef {
+				require.NotEqual(t, commit.Id, commitBeforeRefMerge.Id)
+			}
+		})
+	}
+}
+
+func TestFailedUserMergeToRefRequest(t *testing.T) {
+	server, serverSocketPath := runOperationServiceServer(t)
+	defer server.Stop()
+
+	client, conn := newOperationClient(t, serverSocketPath)
+	defer conn.Close()
+
+	testRepo, testRepoPath, cleanupFn := testhelper.NewTestRepo(t)
+	defer cleanupFn()
+
+	prepareMergeBranch(t, testRepoPath)
+
+	validTargetRef := []byte("refs/merge-requests/x/merge")
+
+	testCases := []struct {
+		desc      string
+		user      *gitalypb.User
+		branch    []byte
+		targetRef []byte
+		sourceSha string
+		repo      *gitalypb.Repository
+		code      codes.Code
+	}{
+		{
+			desc:      "empty repository",
+			user:      mergeUser,
+			branch:    []byte(branchName),
+			sourceSha: commitToMerge,
+			targetRef: validTargetRef,
+			code:      codes.InvalidArgument,
+		},
+		{
+			desc:      "empty user",
+			repo:      testRepo,
+			branch:    []byte(branchName),
+			sourceSha: commitToMerge,
+			targetRef: validTargetRef,
+			code:      codes.InvalidArgument,
+		},
+		{
+			desc:      "empty source SHA",
+			repo:      testRepo,
+			user:      mergeUser,
+			branch:    []byte(branchName),
+			targetRef: validTargetRef,
+			code:      codes.InvalidArgument,
+		},
+		{
+			desc:      "non-existing commit",
+			repo:      testRepo,
+			user:      mergeUser,
+			branch:    []byte(branchName),
+			sourceSha: "f001",
+			targetRef: validTargetRef,
+			code:      codes.InvalidArgument,
+		},
+		{
+			desc:      "empty branch",
+			repo:      testRepo,
+			user:      mergeUser,
+			sourceSha: commitToMerge,
+			targetRef: validTargetRef,
+			code:      codes.InvalidArgument,
+		},
+		{
+			desc:      "non-existing branch",
+			repo:      testRepo,
+			user:      mergeUser,
+			branch:    []byte("this-isnt-real"),
+			sourceSha: commitToMerge,
+			targetRef: validTargetRef,
+			code:      codes.InvalidArgument,
+		},
+	}
+
+	for _, testCase := range testCases {
+		t.Run(testCase.desc, func(t *testing.T) {
+			ctx, cancel := testhelper.Context()
+			defer cancel()
+
+			request := &gitalypb.UserMergeToRefRequest{
+				Repository: testCase.repo,
+				User:       testCase.user,
+				Branch:     testCase.branch,
+				SourceSha:  testCase.sourceSha,
+				TargetRef:  testCase.targetRef,
+			}
+			_, err := client.UserMergeToRef(ctx, request)
+			testhelper.RequireGrpcError(t, err, testCase.code)
+		})
+	}
+}
+
+func TestUserMergeToRefFailedDueToHooksRequest(t *testing.T) {
+	server, serverSocketPath := runOperationServiceServer(t)
+	defer server.Stop()
+
+	client, conn := newOperationClient(t, serverSocketPath)
+	defer conn.Close()
+
+	testRepo, testRepoPath, cleanupFn := testhelper.NewTestRepo(t)
+	defer cleanupFn()
+
+	prepareMergeBranch(t, testRepoPath)
+
+	targetRef := []byte("refs/merge-requests/x/merge")
+	mergeCommitMessage := "Merged by Gitaly"
+
+	request := &gitalypb.UserMergeToRefRequest{
+		Repository: testRepo,
+		SourceSha:  commitToMerge,
+		Branch:     []byte(mergeBranchName),
+		TargetRef:  targetRef,
+		User:       mergeUser,
+		Message:    []byte(mergeCommitMessage),
+	}
+
+	hookContent := []byte("#!/bin/sh\necho 'failure'\nexit 1")
+
+	for _, hookName := range gitlabPreHooks {
+		t.Run(hookName, func(t *testing.T) {
+			remove, err := OverrideHooks(hookName, hookContent)
+			require.NoError(t, err)
+			defer remove()
+
+			ctx, cancel := testhelper.Context()
+			defer cancel()
+
+			resp, err := client.UserMergeToRef(ctx, request)
+			require.Nil(t, err)
+			require.Contains(t, resp.PreReceiveError, "failure")
+		})
+	}
+}
+
 func prepareMergeBranch(t *testing.T, testRepoPath string) {
 	deleteBranch(testRepoPath, mergeBranchName)
 	out, err := exec.Command("git", "-C", testRepoPath, "branch", mergeBranchName, mergeBranchHeadBefore).CombinedOutput()
