@@ -1,7 +1,10 @@
 package repository
 
 import (
+	"context"
+
 	"gitlab.com/gitlab-org/gitaly-proto/go/gitalypb"
+	"gitlab.com/gitlab-org/gitaly/internal/helper"
 	"gitlab.com/gitlab-org/gitaly/internal/rubyserver"
 )
 
@@ -13,3 +16,7 @@ type server struct {
 func NewServer(rs *rubyserver.Server) gitalypb.RepositoryServiceServer {
 	return &server{Server: rs}
 }
+
+func (*server) FetchHTTPRemote(context.Context, *gitalypb.FetchHTTPRemoteRequest) (*gitalypb.FetchHTTPRemoteResponse, error) {
+	return nil, helper.Unimplemented
+}
