@@ -1,11 +1,11 @@
 package repository
 
 import (
+	"context"
 	"fmt"
 
 	"gitlab.com/gitlab-org/gitaly-proto/go/gitalypb"
 	"gitlab.com/gitlab-org/gitaly/internal/git"
-	"golang.org/x/net/context"
 )
 
 func removeOriginInRepo(ctx context.Context, repository *gitalypb.Repository) error {
