@@ -148,10 +148,8 @@ func TestReceivePackPushHookFailure(t *testing.T) {
 	require.NoError(t, err)
 	defer os.RemoveAll(hookDir)
 
-	defer func(oldDir string) {
-		config.Config.GitlabShell.Dir = oldDir
-	}(config.Config.GitlabShell.Dir)
-	config.Config.GitlabShell.Dir = hookDir
+	defer func() { hooks.Override = "" }()
+	hooks.Override = hookDir
 
 	require.NoError(t, os.MkdirAll(hooks.Path(), 0755))
 
