@@ -3,8 +3,9 @@ package testhelper
 import (
 	"bytes"
 	"fmt"
-	"strings"
 	"testing"
+
+	"gitlab.com/gitlab-org/gitaly/internal/helper/text"
 )
 
 // CreateTagOpts holds extra options for CreateTag.
@@ -40,6 +41,6 @@ func CreateTag(t *testing.T, repoPath, tagName, targetID string, opts *CreateTag
 
 	MustRunCommand(t, stdin, "git", args...)
 
-	tagID := MustRunCommand(t, nil, "git", "-C", repoPath, "rev-parse", tagName)
-	return strings.TrimSpace(string(tagID))
+	tagID := MustRunCommand(t, nil, "git", "-C", repoPath, "show-ref", "-s", tagName)
+	return text.ChompBytes(tagID)
 }
