@@ -62,10 +62,9 @@ module Gitlab
           repo = Rugged::Repository.init_at(repo_path, true)
           repo.close
 
-          # TODO: remove this when self healing hooks has been merged at least
-          # one release ago: https://gitlab.com/gitlab-org/gitaly/merge_requests/886
-          symlink_hooks_to = Gitlab::Git::Hook.directory
-          create_hooks(repo_path, symlink_hooks_to) if symlink_hooks_to.present?
+          # TODO: stop symlinking to the old hooks location in or after GitLab 12.0.
+          # https://gitlab.com/gitlab-org/gitaly/issues/1392
+          create_hooks(repo_path, Gitlab::Git::Hook.legacy_hooks_directory)
         end
 
         def create_hooks(repo_path, global_hooks_path)
@@ -261,55 +260,6 @@ module Gitlab
         false
       end
 
-      # TODO: remove after 11.8 because of https://gitlab.com/gitlab-org/gitaly/merge_requests/1026
-      def raw_changes_between(old_rev, new_rev)
-        @raw_changes_between ||= {}
-
-        @raw_changes_between[[old_rev, new_rev]] ||=
-          begin
-            return [] if new_rev.blank? || new_rev == Gitlab::Git::BLANK_SHA
-
-            result = []
-
-            Open3.popen3(*git_diff_cmd(old_rev, new_rev)) do |_stdin, stdout, _stderr, wait_thr|
-              cat_stdin, cat_stdout, cat_stderr, cat_wait_thr = Open3.popen3(*git_cat_file_cmd)
-
-              stdout.each_line do |line|
-                old_mode, new_mode, blob_id, rest = parse_raw_diff_line(line)
-                cat_stdin.puts("#{blob_id} #{rest}")
-                result << ::Gitlab::Git::RawDiffChange.new(cat_stdout.gets.chomp, old_mode, new_mode)
-              end
-
-              cat_stdin.close
-              cat_stdout.close
-              cat_stderr.close
-
-              raise ::Gitlab::Git::Repository::GitError, "Unabled to obtain changes between #{old_rev} and #{new_rev}" unless [cat_wait_thr, wait_thr].all? { |waiter| waiter.value&.success? }
-            end
-
-            result
-          end
-      rescue ArgumentError => e
-        raise Gitlab::Git::Repository::GitError, e.to_s
-      end
-
-      # TODO: remove after 11.8 because of https://gitlab.com/gitlab-org/gitaly/merge_requests/1026
-      def parse_raw_diff_line(line)
-        old_mode, new_mode, old_blob_id, new_blob_id, rest = line.split(/\s/, 5)
-
-        # If the last element got a value we should be good
-        raise ArgumentError, "Invalid diff line: #{line}" unless rest
-
-        old_mode.gsub!(/\A:/, '')
-        old_blob_id.gsub!(/[^\h]/, '')
-        new_blob_id.gsub!(/[^\h]/, '')
-
-        # We can't pass '0000000...' to `git cat-file` given it will not return info about the deleted file
-        blob_id = new_blob_id.match?(/\A0+\z/) ? old_blob_id : new_blob_id
-
-        [old_mode, new_mode, blob_id, rest]
-      end
-
       def add_tag(tag_name, user:, target:, message: nil)
         target_object = Ref.dereference_object(lookup(target))
         raise InvalidRef, "target not found: #{target}" unless target_object
@@ -356,28 +306,29 @@ module Gitlab
         tags.find { |tag| tag.name.b == name_b }
       end
 
-      def merge(user, source_sha, target_branch, message)
-        committer = Gitlab::Git.committer_hash(email: user.email, name: user.name)
+      def merge_to_ref(user, source_sha, branch, target_ref, message)
+        branch = find_branch(branch)
 
+        raise InvalidRef unless branch
+
+        OperationService.new(user, self).commit_ref(target_ref, from_branch: branch) do
+          our_commit = branch.target
+          their_commit = source_sha
+
+          create_merge_commit(user, our_commit, their_commit, message)
+        end
+      rescue Gitlab::Git::CommitError # when merge_index.conflicts?
+        nil
+      rescue Rugged::ReferenceError, InvalidRef
+        raise ArgumentError, 'Invalid merge source'
+      end
+
+      def merge(user, source_sha, target_branch, message)
         OperationService.new(user, self).with_branch(target_branch) do |start_commit|
           our_commit = start_commit.sha
           their_commit = source_sha
 
-          raise 'Invalid merge target' unless our_commit
-          raise 'Invalid merge source' unless their_commit
-
-          merge_index = rugged.merge_commits(our_commit, their_commit)
-          break if merge_index.conflicts?
-
-          options = {
-            parents: [our_commit, their_commit],
-            tree: merge_index.write_tree(rugged),
-            message: message,
-            author: committer,
-            committer: committer
-          }
-
-          commit_id = create_commit(options)
+          commit_id = create_merge_commit(user, our_commit, their_commit, message)
 
           yield commit_id
 
@@ -475,7 +426,7 @@ module Gitlab
         with_worktree(squash_path, branch, sparse_checkout_files: diff_files, env: env) do
           # Apply diff of the `diff_range` to the worktree
           diff = run_git!(%W[diff --binary #{diff_range}])
-          run_git!(%w[apply --index --whitespace=nowarn], chdir: squash_path, env: env, include_stderr: true) do |stdin|
+          run_git!(%w[apply --index --3way --whitespace=nowarn], chdir: squash_path, env: env, include_stderr: true) do |stdin|
             stdin.binmode
             stdin.write(diff)
           end
@@ -536,16 +487,18 @@ module Gitlab
         end
       end
 
+      # rubocop:disable Metrics/ParameterLists
       def multi_action(
         user, branch_name:, message:, actions:,
         author_email: nil, author_name: nil,
-        start_branch_name: nil, start_repository: self
+        start_branch_name: nil, start_repository: self, force: false
       )
 
         OperationService.new(user, self).with_branch(
           branch_name,
           start_branch_name: start_branch_name,
-          start_repository: start_repository
+          start_repository: start_repository,
+          force: force
         ) do |start_commit|
 
           index = Gitlab::Git::Index.new(self)
@@ -571,21 +524,7 @@ module Gitlab
           create_commit(options)
         end
       end
-
-      def raw_log(options)
-        sha =
-          unless options[:all]
-            actual_ref = options[:ref] || root_ref
-            begin
-              sha_from_ref(actual_ref)
-            rescue Rugged::OdbError, Rugged::InvalidError, Rugged::ReferenceError
-              # Return an empty array if the ref wasn't found
-              return []
-            end
-          end
-
-        log_by_shell(sha, options)
-      end
+      # rubocop:enable Metrics/ParameterLists
 
       def with_repo_branch_commit(start_repository, start_branch_name)
         Gitlab::Git.check_namespace!(start_repository)
@@ -838,6 +777,26 @@ module Gitlab
 
       private
 
+      def create_merge_commit(user, our_commit, their_commit, message)
+        raise 'Invalid merge target' unless our_commit
+        raise 'Invalid merge source' unless their_commit
+
+        committer = user_to_committer(user)
+
+        merge_index = rugged.merge_commits(our_commit, their_commit)
+        return if merge_index.conflicts?
+
+        options = {
+          parents: [our_commit, their_commit],
+          tree: merge_index.write_tree(rugged),
+          author: committer,
+          committer: committer,
+          message: message
+        }
+
+        create_commit(options)
+      end
+
       def run_git(args, chdir: path, env: {}, nice: false, include_stderr: false, lazy_block: nil, &block)
         cmd = [Gitlab.config.git.bin_path, *args]
         cmd.unshift("nice") if nice
@@ -889,70 +848,6 @@ module Gitlab
         sort_branches(branches, sort_by)
       end
 
-      def log_by_shell(sha, options)
-        limit = options[:limit].to_i
-        offset = options[:offset].to_i
-        use_follow_flag = options[:follow] && options[:path].present?
-
-        # We will perform the offset in Ruby because --follow doesn't play well with --skip.
-        # See: https://gitlab.com/gitlab-org/gitlab-ce/issues/3574#note_3040520
-        offset_in_ruby = use_follow_flag && options[:offset].present?
-        limit += offset if offset_in_ruby
-
-        cmd = %w[log]
-        cmd << "--max-count=#{limit}"
-        cmd << '--format=%H'
-        cmd << "--skip=#{offset}" unless offset_in_ruby
-        cmd << '--follow' if use_follow_flag
-        cmd << '--no-merges' if options[:skip_merges]
-        cmd << "--after=#{options[:after].iso8601}" if options[:after]
-        cmd << "--before=#{options[:before].iso8601}" if options[:before]
-
-        if options[:all]
-          cmd += %w[--all --reverse]
-        else
-          cmd << sha
-        end
-
-        # :path can be a string or an array of strings
-        if options[:path].present?
-          cmd << '--'
-          cmd += Array(options[:path])
-        end
-
-        # Disable stderr because Git can show warnings that corrupt the output stream
-        raw_output, _status = run_git(cmd, include_stderr: false)
-        lines = offset_in_ruby ? raw_output.lines.drop(offset) : raw_output.lines
-
-        lines.map! { |c| Rugged::Commit.new(rugged, c.strip) }
-      end
-
-      def build_git_cmd(*args)
-        object_directories = alternate_object_directories.join(File::PATH_SEPARATOR)
-
-        env = { 'PWD' => path }
-        env['GIT_ALTERNATE_OBJECT_DIRECTORIES'] = object_directories if object_directories.present?
-
-        [
-          env,
-          ::Gitlab.config.git.bin_path,
-          *args,
-          { chdir: path }
-        ]
-      end
-
-      # TODO: remove after 11.8 because of https://gitlab.com/gitlab-org/gitaly/merge_requests/1026
-      def git_diff_cmd(old_rev, new_rev)
-        old_rev = old_rev == ::Gitlab::Git::BLANK_SHA ? ::Gitlab::Git::EMPTY_TREE_ID : old_rev
-
-        build_git_cmd('diff', old_rev, new_rev, '--raw')
-      end
-
-      def git_cat_file_cmd
-        format = '%(objectname) %(objectsize) %(rest)'
-        build_git_cmd('cat-file', "--batch-check=#{format}")
-      end
-
       def git_delete_refs(*ref_names)
         instructions = ref_names.map do |ref|
           "delete #{ref}\x00\x00"
@@ -1075,10 +970,6 @@ module Gitlab
         end
       end
 
-      def sha_from_ref(ref)
-        rev_parse_target(ref).oid
-      end
-
       def gitlab_projects_error
         raise CommandError, @gitlab_projects.output
       end
